@@ -20,15 +20,7 @@ import numpy as np
 
 import raven.struct.dataframe.core as dataframe
 import raven.struct.dataframe.column as column
-import raven.struct.dataframe.shortcolumn as shortcolumn
-import raven.struct.dataframe.intcolumn as intcolumn
-import raven.struct.dataframe.longcolumn as longcolumn
-import raven.struct.dataframe.floatcolumn as floatcolumn
-import raven.struct.dataframe.doublecolumn as doublecolumn
-import raven.struct.dataframe.stringcolumn as stringcolumn
-import raven.struct.dataframe.charcolumn as charcolumn
-import raven.struct.dataframe.booleancolumn as booleancolumn
-import raven.struct.dataframe.binarycolumn as binarycolumn
+import raven.struct.dataframe._columnutils as utils
 
 class ByteColumn(column.Column):
     """A Column holding byte values (int8).
@@ -129,74 +121,78 @@ class ByteColumn(column.Column):
         converted = None
         if typecode == ByteColumn.TYPE_CODE:
             converted = self.clone()
-        elif typecode == shortcolumn.ShortColumn.TYPE_CODE:
-            converted = shortcolumn.ShortColumn(values=self._values.astype(np.int16))
-        elif typecode == intcolumn.IntColumn.TYPE_CODE:
-            converted = intcolumn.IntColumn(values=self._values.astype(np.int32))
-        elif typecode == longcolumn.LongColumn.TYPE_CODE:
-            converted = longcolumn.LongColumn(values=self._values.astype(np.int64))
-        elif typecode == stringcolumn.StringColumn.TYPE_CODE:
+        elif typecode == utils.type_code_short_column():
+            converted = dataframe.DataFrame.ShortColumn(values=self._values.astype(np.int16))
+        elif typecode == utils.type_code_int_column():
+            converted = dataframe.DataFrame.IntColumn(values=self._values.astype(np.int32))
+        elif typecode == utils.type_code_long_column():
+            converted = dataframe.DataFrame.LongColumn(values=self._values.astype(np.int64))
+        elif typecode == utils.type_code_string_column():
             vals = self._values.astype(np.object)
             for i, x in np.ndenumerate(vals):
                 vals[i] = str(x)
 
-            converted = stringcolumn.StringColumn(values=vals)
-        elif typecode == floatcolumn.FloatColumn.TYPE_CODE:
-            converted = floatcolumn.FloatColumn(values=self._values.astype(np.float32))
-        elif typecode == doublecolumn.DoubleColumn.TYPE_CODE:
-            converted = doublecolumn.DoubleColumn(values=self._values.astype(np.float64))
-        elif typecode == charcolumn.CharColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.StringColumn(values=vals)
+        elif typecode == utils.type_code_float_column():
+            converted = dataframe.DataFrame.FloatColumn(values=self._values.astype(np.float32))
+        elif typecode == utils.type_code_double_column():
+            converted = dataframe.DataFrame.DoubleColumn(values=self._values.astype(np.float64))
+        elif typecode == utils.type_code_char_column():
             vals = self._values.astype(np.uint8)
             for i, x in np.ndenumerate(vals):
                 vals[i] = ord(str(x)[0])
 
-            converted = charcolumn.CharColumn(values=vals)
-        elif typecode == booleancolumn.BooleanColumn.TYPE_CODE:
-            converted = booleancolumn.BooleanColumn(values=self._values.astype(np.bool))
-        elif typecode == binarycolumn.BinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.CharColumn(values=vals)
+        elif typecode == utils.type_code_boolean_column():
+            converted = dataframe.DataFrame.BooleanColumn(values=self._values.astype(np.bool))
+        elif typecode == utils.type_code_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = bytearray(int(x).to_bytes(1, byteorder="big", signed=True))
 
-            converted = binarycolumn.BinaryColumn(values=vals)
+            converted = dataframe.DataFrame.BinaryColumn(values=vals)
         elif typecode == NullableByteColumn.TYPE_CODE:
             converted = NullableByteColumn(values=self._values.astype(np.object))
-        elif typecode == shortcolumn.NullableShortColumn.TYPE_CODE:
-            converted = shortcolumn.NullableShortColumn(values=self._values.astype(np.object))
-        elif typecode == intcolumn.NullableIntColumn.TYPE_CODE:
-            converted = intcolumn.NullableIntColumn(values=self._values.astype(np.object))
-        elif typecode == longcolumn.NullableLongColumn.TYPE_CODE:
-            converted = longcolumn.NullableLongColumn(values=self._values.astype(np.object))
-        elif typecode == stringcolumn.NullableStringColumn.TYPE_CODE:
+        elif typecode == utils.type_code_nullable_short_column():
+            converted = dataframe.DataFrame.NullableShortColumn(
+                values=self._values.astype(np.object))
+
+        elif typecode == utils.type_code_nullable_int_column():
+            converted = dataframe.DataFrame.NullableIntColumn(values=self._values.astype(np.object))
+        elif typecode == utils.type_code_nullable_long_column():
+            converted = dataframe.DataFrame.NullableLongColumn(
+                values=self._values.astype(np.object))
+
+        elif typecode == utils.type_code_nullable_string_column():
             vals = self._values.astype(np.object)
             for i, x in np.ndenumerate(vals):
                 vals[i] = str(x)
 
-            converted = stringcolumn.NullableStringColumn(values=vals)
-        elif typecode == floatcolumn.NullableFloatColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableStringColumn(values=vals)
+        elif typecode == utils.type_code_nullable_float_column():
             vals = self._values.astype(np.float32)
             vals = vals.astype(np.object)
-            converted = floatcolumn.NullableFloatColumn(values=vals)
-        elif typecode == doublecolumn.NullableDoubleColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableFloatColumn(values=vals)
+        elif typecode == utils.type_code_nullable_double_column():
             vals = self._values.astype(np.float64)
             vals = vals.astype(np.object)
-            converted = doublecolumn.NullableDoubleColumn(values=vals)
-        elif typecode == charcolumn.NullableCharColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableDoubleColumn(values=vals)
+        elif typecode == utils.type_code_nullable_char_column():
             vals = self._values.astype(np.object)
             for i, x in np.ndenumerate(vals):
                 vals[i] = ord(str(x)[0])
 
-            converted = charcolumn.NullableCharColumn(values=vals)
-        elif typecode == booleancolumn.NullableBooleanColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableCharColumn(values=vals)
+        elif typecode == utils.type_code_nullable_boolean_column():
             vals = self._values.astype(np.bool)
             vals = vals.astype(np.object)
-            converted = booleancolumn.NullableBooleanColumn(values=vals)
-        elif typecode == binarycolumn.NullableBinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableBooleanColumn(values=vals)
+        elif typecode == utils.type_code_nullable_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = bytearray(int(x).to_bytes(1, byteorder="big", signed=True))
 
-            converted = binarycolumn.NullableBinaryColumn(values=vals)
+            converted = dataframe.DataFrame.NullableBinaryColumn(values=vals)
         else:
             raise dataframe.DataFrameException(
                 "Unknown column type code: {}".format(typecode))
@@ -316,7 +312,7 @@ class NullableByteColumn(column.Column):
                     vals[i] = 0
 
             converted = ByteColumn(values=vals)
-        elif typecode == shortcolumn.ShortColumn.TYPE_CODE:
+        elif typecode == utils.type_code_short_column():
             vals = np.empty([self._values.shape[0]], dtype=np.int16)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -324,8 +320,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = 0
 
-            converted = shortcolumn.ShortColumn(values=vals)
-        elif typecode == intcolumn.IntColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.ShortColumn(values=vals)
+        elif typecode == utils.type_code_int_column():
             vals = np.empty([self._values.shape[0]], dtype=np.int32)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -333,8 +329,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = 0
 
-            converted = intcolumn.IntColumn(values=vals)
-        elif typecode == longcolumn.LongColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.IntColumn(values=vals)
+        elif typecode == utils.type_code_long_column():
             vals = np.empty([self._values.shape[0]], dtype=np.int64)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -342,17 +338,17 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = 0
 
-            converted = longcolumn.LongColumn(values=vals)
-        elif typecode == stringcolumn.StringColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.LongColumn(values=vals)
+        elif typecode == utils.type_code_string_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
                     vals[i] = str(x)
                 else:
-                    vals[i] = stringcolumn.StringColumn.DEFAULT_VALUE
+                    vals[i] = utils.default_value_string_column()
 
-            converted = stringcolumn.StringColumn(values=vals)
-        elif typecode == floatcolumn.FloatColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.StringColumn(values=vals)
+        elif typecode == utils.type_code_float_column():
             vals = np.empty([self._values.shape[0]], dtype=np.float32)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -360,8 +356,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = 0.0
 
-            converted = floatcolumn.FloatColumn(values=vals)
-        elif typecode == doublecolumn.DoubleColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.FloatColumn(values=vals)
+        elif typecode == utils.type_code_double_column():
             vals = np.empty([self._values.shape[0]], dtype=np.float64)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -369,17 +365,18 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = 0.0
 
-            converted = doublecolumn.DoubleColumn(values=vals)
-        elif typecode == charcolumn.CharColumn.TYPE_CODE:
-            vals = np.empty([self._values.shape[0]], dtype=np.uint8)
+            converted = dataframe.DataFrame.DoubleColumn(values=vals)
+        elif typecode == utils.type_code_char_column():
+            vals = np.zeros([self._values.shape[0]], dtype=np.uint8)
+            ord_default = ord(utils.default_value_char_column())
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
                     vals[i] = ord(str(x)[0])
                 else:
-                    vals[i] = charcolumn.CharColumn.DEFAULT_VALUE
+                    vals[i] = ord_default
 
-            converted = charcolumn.CharColumn(values=vals)
-        elif typecode == booleancolumn.BooleanColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.CharColumn(values=vals)
+        elif typecode == utils.type_code_boolean_column():
             vals = np.empty([self._values.shape[0]], dtype=np.bool)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -387,8 +384,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = False
 
-            converted = booleancolumn.BooleanColumn(values=vals)
-        elif typecode == binarycolumn.BinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.BooleanColumn(values=vals)
+        elif typecode == utils.type_code_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -396,28 +393,28 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = bytearray(int(0).to_bytes(1, byteorder="big", signed=True))
 
-            converted = binarycolumn.BinaryColumn(values=vals)
+            converted = dataframe.DataFrame.BinaryColumn(values=vals)
         elif typecode == NullableByteColumn.TYPE_CODE:
             converted = self.clone()
-        elif typecode == shortcolumn.NullableShortColumn.TYPE_CODE:
+        elif typecode == utils.type_code_nullable_short_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = int(np.int16(x)) if x is not None else None
 
-            converted = shortcolumn.NullableShortColumn(values=vals)
-        elif typecode == intcolumn.NullableIntColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableShortColumn(values=vals)
+        elif typecode == utils.type_code_nullable_int_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = int(np.int32(x)) if x is not None else None
 
-            converted = intcolumn.NullableIntColumn(values=vals)
-        elif typecode == longcolumn.NullableLongColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableIntColumn(values=vals)
+        elif typecode == utils.type_code_nullable_long_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = int(np.int64(x)) if x is not None else None
 
-            converted = longcolumn.NullableLongColumn(values=vals)
-        elif typecode == stringcolumn.NullableStringColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableLongColumn(values=vals)
+        elif typecode == utils.type_code_nullable_string_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -425,8 +422,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = stringcolumn.NullableStringColumn(values=vals)
-        elif typecode == floatcolumn.NullableFloatColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableStringColumn(values=vals)
+        elif typecode == utils.type_code_nullable_float_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -434,8 +431,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = floatcolumn.NullableFloatColumn(values=vals)
-        elif typecode == doublecolumn.NullableDoubleColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableFloatColumn(values=vals)
+        elif typecode == utils.type_code_nullable_double_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -443,8 +440,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = doublecolumn.NullableDoubleColumn(values=vals)
-        elif typecode == charcolumn.NullableCharColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableDoubleColumn(values=vals)
+        elif typecode == utils.type_code_nullable_char_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -452,8 +449,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = charcolumn.NullableCharColumn(values=vals)
-        elif typecode == booleancolumn.NullableBooleanColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableCharColumn(values=vals)
+        elif typecode == utils.type_code_nullable_boolean_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -461,8 +458,8 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = booleancolumn.NullableBooleanColumn(values=vals)
-        elif typecode == binarycolumn.NullableBinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableBooleanColumn(values=vals)
+        elif typecode == utils.type_code_nullable_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -470,7 +467,7 @@ class NullableByteColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = binarycolumn.NullableBinaryColumn(values=vals)
+            converted = dataframe.DataFrame.NullableBinaryColumn(values=vals)
         else:
             raise dataframe.DataFrameException(
                 "Unknown column type code: {}".format(typecode))
