@@ -20,15 +20,7 @@ import numpy as np
 
 import raven.struct.dataframe.core as dataframe
 import raven.struct.dataframe.column as column
-import raven.struct.dataframe.bytecolumn as bytecolumn
-import raven.struct.dataframe.intcolumn as intcolumn
-import raven.struct.dataframe.longcolumn as longcolumn
-import raven.struct.dataframe.floatcolumn as floatcolumn
-import raven.struct.dataframe.doublecolumn as doublecolumn
-import raven.struct.dataframe.stringcolumn as stringcolumn
-import raven.struct.dataframe.charcolumn as charcolumn
-import raven.struct.dataframe.booleancolumn as booleancolumn
-import raven.struct.dataframe.binarycolumn as binarycolumn
+import raven.struct.dataframe._columnutils as utils
 
 class ShortColumn(column.Column):
     """A Column holding short values (int16).
@@ -127,77 +119,81 @@ class ShortColumn(column.Column):
     # pylint: disable=invalid-name
     def convert_to(self, typecode):
         converted = None
-        if typecode == bytecolumn.ByteColumn.TYPE_CODE:
-            converted = bytecolumn.ByteColumn(values=self._values.astype(np.int8))
+        if typecode == utils.type_code_byte_column():
+            converted = dataframe.DataFrame.ByteColumn(values=self._values.astype(np.int8))
         elif typecode == ShortColumn.TYPE_CODE:
             converted = self.clone()
-        elif typecode == intcolumn.IntColumn.TYPE_CODE:
-            converted = intcolumn.IntColumn(values=self._values.astype(np.int32))
-        elif typecode == longcolumn.LongColumn.TYPE_CODE:
-            converted = longcolumn.LongColumn(values=self._values.astype(np.int64))
-        elif typecode == stringcolumn.StringColumn.TYPE_CODE:
+        elif typecode == utils.type_code_int_column():
+            converted = dataframe.DataFrame.IntColumn(values=self._values.astype(np.int32))
+        elif typecode == utils.type_code_long_column():
+            converted = dataframe.DataFrame.LongColumn(values=self._values.astype(np.int64))
+        elif typecode == utils.type_code_string_column():
             vals = self._values.astype(np.object)
             for i, x in np.ndenumerate(vals):
                 vals[i] = str(x)
 
-            converted = stringcolumn.StringColumn(values=vals)
-        elif typecode == floatcolumn.FloatColumn.TYPE_CODE:
-            converted = floatcolumn.FloatColumn(values=self._values.astype(np.float32))
-        elif typecode == doublecolumn.DoubleColumn.TYPE_CODE:
-            converted = doublecolumn.DoubleColumn(values=self._values.astype(np.float64))
-        elif typecode == charcolumn.CharColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.StringColumn(values=vals)
+        elif typecode == utils.type_code_float_column():
+            converted = dataframe.DataFrame.FloatColumn(values=self._values.astype(np.float32))
+        elif typecode == utils.type_code_double_column():
+            converted = dataframe.DataFrame.DoubleColumn(values=self._values.astype(np.float64))
+        elif typecode == utils.type_code_char_column():
             vals = self._values.astype(np.uint8)
             for i, x in np.ndenumerate(vals):
                 vals[i] = ord(str(x)[0])
 
-            converted = charcolumn.CharColumn(values=vals)
-        elif typecode == booleancolumn.BooleanColumn.TYPE_CODE:
-            converted = booleancolumn.BooleanColumn(values=self._values.astype(np.bool))
-        elif typecode == binarycolumn.BinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.CharColumn(values=vals)
+        elif typecode == utils.type_code_boolean_column():
+            converted = dataframe.DataFrame.BooleanColumn(values=self._values.astype(np.bool))
+        elif typecode == utils.type_code_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = bytearray(int(x).to_bytes(2, byteorder="big", signed=True))
 
-            converted = binarycolumn.BinaryColumn(values=vals)
-        elif typecode == bytecolumn.NullableByteColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.BinaryColumn(values=vals)
+        elif typecode == utils.type_code_nullable_byte_column():
             vals = self._values.astype(np.int8)
-            converted = bytecolumn.NullableByteColumn(values=vals.astype(np.object))
+            converted = dataframe.DataFrame.NullableByteColumn(values=vals.astype(np.object))
         elif typecode == NullableShortColumn.TYPE_CODE:
             converted = NullableShortColumn(values=self._values.astype(np.object))
-        elif typecode == intcolumn.NullableIntColumn.TYPE_CODE:
-            converted = intcolumn.NullableIntColumn(values=self._values.astype(np.object))
-        elif typecode == longcolumn.NullableLongColumn.TYPE_CODE:
-            converted = longcolumn.NullableLongColumn(values=self._values.astype(np.object))
-        elif typecode == stringcolumn.NullableStringColumn.TYPE_CODE:
+        elif typecode == utils.type_code_nullable_int_column():
+            converted = dataframe.DataFrame.NullableIntColumn(
+                values=self._values.astype(np.object))
+
+        elif typecode == utils.type_code_nullable_long_column():
+            converted = dataframe.DataFrame.NullableLongColumn(
+                values=self._values.astype(np.object))
+
+        elif typecode == utils.type_code_nullable_string_column():
             vals = self._values.astype(np.object)
             for i, x in np.ndenumerate(vals):
                 vals[i] = str(x)
 
-            converted = stringcolumn.NullableStringColumn(values=vals)
-        elif typecode == floatcolumn.NullableFloatColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableStringColumn(values=vals)
+        elif typecode == utils.type_code_nullable_float_column():
             vals = self._values.astype(np.float32)
             vals = vals.astype(np.object)
-            converted = floatcolumn.NullableFloatColumn(values=vals)
-        elif typecode == doublecolumn.NullableDoubleColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableFloatColumn(values=vals)
+        elif typecode == utils.type_code_nullable_double_column():
             vals = self._values.astype(np.float64)
             vals = vals.astype(np.object)
-            converted = doublecolumn.NullableDoubleColumn(values=vals)
-        elif typecode == charcolumn.NullableCharColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableDoubleColumn(values=vals)
+        elif typecode == utils.type_code_nullable_char_column():
             vals = self._values.astype(np.object)
             for i, x in np.ndenumerate(vals):
                 vals[i] = ord(str(x)[0])
 
-            converted = charcolumn.NullableCharColumn(values=vals)
-        elif typecode == booleancolumn.NullableBooleanColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableCharColumn(values=vals)
+        elif typecode == utils.type_code_nullable_boolean_column():
             vals = self._values.astype(np.bool)
             vals = vals.astype(np.object)
-            converted = booleancolumn.NullableBooleanColumn(values=vals)
-        elif typecode == binarycolumn.NullableBinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableBooleanColumn(values=vals)
+        elif typecode == utils.type_code_nullable_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = bytearray(int(x).to_bytes(2, byteorder="big", signed=True))
 
-            converted = binarycolumn.NullableBinaryColumn(values=vals)
+            converted = dataframe.DataFrame.NullableBinaryColumn(values=vals)
         else:
             raise dataframe.DataFrameException(
                 "Unknown column type code: {}".format(typecode))
@@ -308,7 +304,7 @@ class NullableShortColumn(column.Column):
     # pylint: disable=invalid-name
     def convert_to(self, typecode):
         converted = None
-        if typecode == bytecolumn.ByteColumn.TYPE_CODE:
+        if typecode == utils.type_code_byte_column():
             vals = np.empty([self._values.shape[0]], dtype=np.int8)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -316,7 +312,7 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = 0
 
-            converted = bytecolumn.ByteColumn(values=vals)
+            converted = dataframe.DataFrame.ByteColumn(values=vals)
         elif typecode == ShortColumn.TYPE_CODE:
             vals = np.empty([self._values.shape[0]], dtype=np.int16)
             for i, x in np.ndenumerate(self._values):
@@ -326,7 +322,7 @@ class NullableShortColumn(column.Column):
                     vals[i] = 0
 
             converted = ShortColumn(values=vals)
-        elif typecode == intcolumn.IntColumn.TYPE_CODE:
+        elif typecode == utils.type_code_int_column():
             vals = np.empty([self._values.shape[0]], dtype=np.int32)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -334,8 +330,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = 0
 
-            converted = intcolumn.IntColumn(values=vals)
-        elif typecode == longcolumn.LongColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.IntColumn(values=vals)
+        elif typecode == utils.type_code_long_column():
             vals = np.empty([self._values.shape[0]], dtype=np.int64)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -343,17 +339,17 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = 0
 
-            converted = longcolumn.LongColumn(values=vals)
-        elif typecode == stringcolumn.StringColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.LongColumn(values=vals)
+        elif typecode == utils.type_code_string_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
                     vals[i] = str(x)
                 else:
-                    vals[i] = stringcolumn.StringColumn.DEFAULT_VALUE
+                    vals[i] = utils.default_value_string_column()
 
-            converted = stringcolumn.StringColumn(values=vals)
-        elif typecode == floatcolumn.FloatColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.StringColumn(values=vals)
+        elif typecode == utils.type_code_float_column():
             vals = np.empty([self._values.shape[0]], dtype=np.float32)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -361,8 +357,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = 0.0
 
-            converted = floatcolumn.FloatColumn(values=vals)
-        elif typecode == doublecolumn.DoubleColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.FloatColumn(values=vals)
+        elif typecode == utils.type_code_double_column():
             vals = np.empty([self._values.shape[0]], dtype=np.float64)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -370,17 +366,18 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = 0.0
 
-            converted = doublecolumn.DoubleColumn(values=vals)
-        elif typecode == charcolumn.CharColumn.TYPE_CODE:
-            vals = np.empty([self._values.shape[0]], dtype=np.uint8)
+            converted = dataframe.DataFrame.DoubleColumn(values=vals)
+        elif typecode == utils.type_code_char_column():
+            vals = np.zeros([self._values.shape[0]], dtype=np.uint8)
+            ord_default = ord(utils.default_value_char_column())
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
                     vals[i] = ord(str(x)[0])
                 else:
-                    vals[i] = charcolumn.CharColumn.DEFAULT_VALUE
+                    vals[i] = ord_default
 
-            converted = charcolumn.CharColumn(values=vals)
-        elif typecode == booleancolumn.BooleanColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.CharColumn(values=vals)
+        elif typecode == utils.type_code_boolean_column():
             vals = np.empty([self._values.shape[0]], dtype=np.bool)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -388,8 +385,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = False
 
-            converted = booleancolumn.BooleanColumn(values=vals)
-        elif typecode == binarycolumn.BinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.BooleanColumn(values=vals)
+        elif typecode == utils.type_code_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -397,28 +394,28 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = bytearray(int(0).to_bytes(2, byteorder="big", signed=True))
 
-            converted = binarycolumn.BinaryColumn(values=vals)
-        elif typecode == bytecolumn.NullableByteColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.BinaryColumn(values=vals)
+        elif typecode == utils.type_code_nullable_byte_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = int(np.int8(x)) if x is not None else None
 
-            converted = bytecolumn.NullableByteColumn(values=vals)
+            converted = dataframe.DataFrame.NullableByteColumn(values=vals)
         elif typecode == NullableShortColumn.TYPE_CODE:
             converted = self.clone()
-        elif typecode == intcolumn.NullableIntColumn.TYPE_CODE:
+        elif typecode == utils.type_code_nullable_int_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = int(np.int32(x)) if x is not None else None
 
-            converted = intcolumn.NullableIntColumn(values=vals)
-        elif typecode == longcolumn.NullableLongColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableIntColumn(values=vals)
+        elif typecode == utils.type_code_nullable_long_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 vals[i] = int(np.int64(x)) if x is not None else None
 
-            converted = longcolumn.NullableLongColumn(values=vals)
-        elif typecode == stringcolumn.NullableStringColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableLongColumn(values=vals)
+        elif typecode == utils.type_code_nullable_string_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -426,8 +423,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = stringcolumn.NullableStringColumn(values=vals)
-        elif typecode == floatcolumn.NullableFloatColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableStringColumn(values=vals)
+        elif typecode == utils.type_code_nullable_float_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -435,8 +432,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = floatcolumn.NullableFloatColumn(values=vals)
-        elif typecode == doublecolumn.NullableDoubleColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableFloatColumn(values=vals)
+        elif typecode == utils.type_code_nullable_double_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -444,8 +441,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = doublecolumn.NullableDoubleColumn(values=vals)
-        elif typecode == charcolumn.NullableCharColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableDoubleColumn(values=vals)
+        elif typecode == utils.type_code_nullable_char_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -453,8 +450,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = charcolumn.NullableCharColumn(values=vals)
-        elif typecode == booleancolumn.NullableBooleanColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableCharColumn(values=vals)
+        elif typecode == utils.type_code_nullable_boolean_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -462,8 +459,8 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = booleancolumn.NullableBooleanColumn(values=vals)
-        elif typecode == binarycolumn.NullableBinaryColumn.TYPE_CODE:
+            converted = dataframe.DataFrame.NullableBooleanColumn(values=vals)
+        elif typecode == utils.type_code_nullable_binary_column():
             vals = np.empty([self._values.shape[0]], dtype=np.object)
             for i, x in np.ndenumerate(self._values):
                 if x is not None:
@@ -471,7 +468,7 @@ class NullableShortColumn(column.Column):
                 else:
                     vals[i] = None
 
-            converted = binarycolumn.NullableBinaryColumn(values=vals)
+            converted = dataframe.DataFrame.NullableBinaryColumn(values=vals)
         else:
             raise dataframe.DataFrameException(
                 "Unknown column type code: {}".format(typecode))
